#
# spec file for package python-asdf-astropy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-asdf-astropy%{psuffix}
Version:        0.7.0
Release:        1.2
Summary:        ASDF serialization support for astropy
License:        BSD-3-Clause
URL:            https://github.com/astropy/asdf-astropy
Source:         https://files.pythonhosted.org/packages/source/a/asdf-astropy/asdf_astropy-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module packaging >= 19}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 60}
BuildRequires:  %{python_module setuptools_scm >= 3.4}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-asdf >= 2.14.4
Requires:       python-asdf-coordinates-schemas >= 0.3
Requires:       python-asdf-standard >= 1.1.0
Requires:       python-asdf-transform-schemas >= 0.5
Requires:       python-astropy >= 5.2
Requires:       python-numpy >= 1.24
Requires:       python-packaging >= 19
%if %{with test}
BuildRequires:  %{python_module asdf-astropy = %{version}}
BuildRequires:  %{python_module pytest-astropy}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
%endif
BuildArch:      noarch
%python_subpackages

%description
ASDF serialization support for astropy

%prep
%autosetup -p1 -n asdf_astropy-%{version}
sed -i 's/--color=yes//' pyproject.toml
for c in asdf_astropy/conftest.py; do
  [ -f $c ] || exit 1 # does not exist anymore
  [ ! -s $c ] && echo '# empty module' > $c
done

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest -n auto
%endif

%if !%{with test}
%files %{python_files}
%{python_sitelib}/asdf_astropy
%{python_sitelib}/asdf_astropy-%{version}.dist-info
%endif

%changelog
* Thu Nov 28 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.7.0
  * strip None factor for spectral_density in equivalency converter
    to avoid deprecation warnings for astropy 7. [#229]
  * drop support for python 3.9. [#232]
  * replace usages of copy_arrays with memmap [#230]
  * require asdf 2.14.4 [#241]
  * Add support for astropy.nddata.uncertainty classes [#239]
  * Add support for astropy.wcs.WCS and
    astropy.wcs.wcsapi.SlicedLowLevelWCS [#246]
* Fri May  3 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.1:
  * update copy usage in Quantity converter to deal with astropy
    6.1 changes.
* Fri Mar 15 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.6.0
  * Add python 3.12 support. [#219]
  * Update ASDF standard 1.6.0 support. [#219]
  * Increase minimum versions for asdf-coordinates-schemas
    asdf-transform-schemas and list asdf-standard as
    a dependency. [#219]
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.0:
  * Drop support for Python 3.8 in accordance with NEP 29. [#180]
  * Update ``RepresentationConverter`` for new class paths in
    astropy [#181]
  * Update Converters so that all Class Variables are immutable
  * Remove ``oldest-supported-numpy`` from ``pyproject.toml``
    ``build-system`` as this was never needed and will cause
    problems building on python 3.12 betas.
  * Use unique uri for extensions that implement converters for
    core asdf types [#199]
  * Add support for astropy.table.NdarrayMixin [#200]
  * Update angle converters for new class paths in astropy [#207]
* Thu May 18 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.4.0
  * Update pins for asdf, asdf-coordinates-schemas, numpy, and
    packaging. [#164]
  * Add serialization support for non-VOunits. [#142]
  * Add serialization support for MagUnit based units. [#146]
  * Document and add assert_model_roundtrip and
    assert_table_roundtrip to
  * asdf_astropy.testing.helpers. [#170]
* Thu May 18 2023 Dirk Müller <dmueller@suse.com>
- set sle15_python_module_pythons for building with newer python stack on SLE15
* Tue Dec  6 2022 Ben Greiner <code@bnavigator.de>
- Fix builddeps
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 0.3.0:
  * Update citations.
  * Switch to using ``pyproject.toml`` for package configuration.
  * Fix bug with ``memmap`` of ``Quantity`` objects.
  * Drop support for ``numpy-1.18``.
  * Fix bug with ``str`` representations of ``astropy.time`` objects.
  * Fix bug in preserving the ``dtype`` of ``Quantity`` objects.
* Thu Oct 27 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.2.2
  * Add converter for the new Schechter1D model.
  * Add CITATION file.
  * Add migration and quick-start documentation guides, and update
    minimum Python version.
  * Update FrameConverter to enable the use of multiple tags.
  * Bugfixes for astropy.time converters.
  * Remove unnecessary tag: from schemas.
  * Add converters for ModelBoundingBox and CompoundBoundingBox.
- Drop asdf-astropy-pr84-fixtests.patch
* Sun Jun  5 2022 Ben Greiner <code@bnavigator.de>
- Add asdf-astropy-pr84-fixtests.patch - gh#astropy/asdf-astropy#84
* Wed Apr 27 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.2.1
  * Migrate documentation from astropy to asdf-astropy.
  * Pin astropy min version to 5.0.4.
* Tue Mar 22 2022 Ben Greiner <code@bnavigator.de>
- Fix setuptools_scm[toml] requirement for old distro
* Sun Mar 13 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.2.0
  * Add support for serialization and deserialization of
    input_units_equivalencies for astropy models.
  * Bugfix for units_mapping schema's property name conflicts.
    Changes:
  - inputs to unit_inputs
  - outputs to unit_outputs
  * Add converter support for Cosine1D, Tangent1D, ArcSine1D,
    ArcCosine1D, ArcTangent1D models.
  * Add converter for Spline1D model.
  * Add astropy Table connector for ASDF.
  * Move assert_model_equal to helpers module.
  * Fix warnings raised during testing.
- Make _multibuild in order to avoid build cycles
* Tue Dec 28 2021 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.1.2
- Required by gwcs-0.18
